@@ -54,6 +54,7 @@ class MsgFields(ConstantDict):
     HTTP_HEADERS = "httpheaders"
     IP = "ip"
     IPSET = "ipset"
+    JOB_SETTINGS = "jobsettings"
     LAT = "lat"
     LONG = "long"
     NET_CC = "netcc"
@@ -81,6 +82,8 @@ class MsgFields(ConstantDict):
     URL_CONTENT = "urlcontent"
     URL_SCREENSHOT = "urlscreenshot"
     URL_SPIDER_CONTENT = "urlspidercontent"
+    VIRUSTOTAL_RESULT = "virustotal"
+    VIRUSTOTAL_PREV_HASH = "virustotalprevhash"
     WEB_FINGERPRINTS = "webfingerprints"
     WHOIS = "whois"
     WHOIS_RAW = "raw"
@@ -106,9 +109,10 @@ class MsgFields(ConstantDict):
 
     TASKS_ASNIP = "asnip_task"
     TASKS_GEOIP = "geoip_task"
-    TASKS_HTTP_STATUS = "http_status_task"
     TASKS_HTTP_GET = "http_get_task"
     TASKS_HTTP_SPIDER = "http_spider_task"
+    TASKS_HTTP_STATUS = "http_status_task"
+    TASKS_URL_SCREENSHOT = "url_screenshot"
     TASKS_RESOLVER = "resolver_task"
     TASKS_WEB_FINGERPRINT = "web_fingerprint_task"
     TASKS_OS_FINGERPRINT = "os_fingerprint_task"
@@ -123,6 +127,11 @@ class MsgValues(ConstantDict):
 
     NMAP_STATUS_UP = "up"
 
+    VIRUSTOTAL_HAS_FILE = 1
+    VIRUSTOTAL_MISSING_FILE = 0
+    VIRUSTOTAL_ERROR = -1
+    VIRUSTOTAL_RATE_LIMIT_STATUS = 204
+
     URL_MANIFEST = "urlmani"
     URL_SCREENSHOT_FILE = "urlshot"
 
@@ -130,6 +139,8 @@ class MsgValues(ConstantDict):
 class MsgErrs(ConstantDict):
     FILE_IO_ERROR = "FILE_IO_ERROR::{0}"
 
+    FORMAT_ERROR = "FORMAT_ERROR::{0}"
+
     INPUT_INCORRECT_FORMAT = "INPUT_INCORRECT_FORMAT::{0}"
     INPUT_MISSING = "INPUT_MISSING::{0}"
 
@@ -138,18 +149,25 @@ class MsgErrs(ConstantDict):
 
     LOOKUP_FAILED = "LOOKUP_FAILED::{0}"
 
+    RATE_LIMIT_EXCEEDED = "RATE_LIMIT_EXCEEDED::{0}"
+    REMOTE_API_ERROR = "REMOTE_API_ERROR::{0}"
+
     NMAP_EXEC_ERROR = "NMAP_EXEC_ERROR::{0}"
     NMAP_PARSE_ERROR = "NMAP_PARSE_ERROR::{0}"
 
     RESULT_FAIL = "TASK_RESULT_FAIL::{0}"
     RESULT_INVALID = "RESULT_INVALID::{0}"
 
+    SETTINGS_ERROR = "SETTINGS_ERROR::{0}"
+
     FILE_SIZE_LIMIT_EXCEEDED = "FILE_SIZE_LIMIT_EXCEEDED::{0}"
 
     UNSPECIFIED_ERROR = "UNSPECIFIED_ERROR::{0}"
 
     URL_INVALID = "URL_INVALID::{0}"
     URL_TIMEOUT = "URL_TIMEOUT::{0}"
+    URL_SCREENSHOT_CANCELLED = "URL_SCREENSHOT_CANCELLED::{0}"
     URL_SCREENSHOT_TIMEOUT = "URL_SCREENSHOT_TIMEOUT::{0}"
+    URL_SCREENSHOT_UNAVAILABLE = "URL_SCREENSHOT_UNAVAILABLE::{0}"
     URL_SPIDER_TIMEOUT = "URL_SPIDER_TIMEOUT::{0}"
     URL_CONN_ERROR = "URL_CONN_ERROR::{0}"
