@@ -33,14 +33,16 @@ class TaskResult(dict):
 
     reserved_keys = [F.META]
 
-    def __init__(self, output_name, tmoid, task_name, task_version, data=None,
-                 schema=None):
-        # str name of output type this TaskResult generated
-        # Not used internally, but referenced when adding to TaskResults.
+    def __init__(self, output_name, tmoid, task_name, task_version,
+                 agent_name=None, data=None, schema=None):
+        # str name of output type this TaskResult generated Not used
+        # internally, but referenced when adding to TaskResults.
         self.output_name = output_name
-        # int with the id of the target monitor object
-        # Not used internally, but referenced when adding to TaskResults.
+        # int with the id of the target monitor object Not used internally, but
+        # referenced when adding to TaskResults.
         self.tmoid = tmoid
+        # agent that fulfiled this request
+        self.__agent_name = agent_name
         # str name of the task generating this output.
         self.__task_name = task_name
         # Supplied by task.
@@ -92,11 +94,12 @@ class TaskResult(dict):
         try:
             task_name = data[F.META][F.META_TASK_NAME]
             task_version = data[F.META][F.META_TASK_VERSION]
+            agent_name = data[F.META].get(F.META_AGENT_NAME)
         except KeyError:
             raise ValueError("TaskResult dict does not define a version "
                              "number")
-        return cls(output_name, tmoid, task_name, task_version, data,
-                   schema=schema)
+        return cls(output_name, tmoid, task_name, task_version,
+                   agent_name=agent_name, data=data, schema=schema)
 
     def _set_schema(self, supplied_schema):
         """
@@ -188,10 +191,20 @@ class TaskResult(dict):
         except KeyError:
             return
 
+    @property
+    def agent_name(self):
+        """
+        Return name of agent executing task
+        """
+        try:
+            return self[F.META][F.META_AGENT_NAME]
+        except KeyError:
+            return
+
     @property
     def task_name(self):
         """
-        Return errors returned by a task
+        Return task name that executed
         """
         try:
             return self[F.META][F.META_TASK_NAME]
@@ -247,6 +260,7 @@ class TaskResult(dict):
         self[F.META][F.META_MSG] = msg
         self[F.META][F.META_START_TIME] = self._time_start
         self[F.META][F.META_END_TIME] = self._time_end
+        self[F.META][F.META_AGENT_NAME] = self.__agent_name
         self[F.META][F.META_TASK_NAME] = self.__task_name
         self[F.META][F.META_TASK_VERSION] = self.__task_version
 
