@@ -456,3 +456,23 @@ class TestTaskResultSet(unittest.TestCase):
         ip_tmoid = ipset_tmoid.get_data("ips").keys()
 
         self.assertEqual(ip_tmoid, ["1.1.1.1", "2.2.2.2"])
+
+    def test_random_bucket_schema(self):
+        BucketSchema = build_schema({
+            "properties": {
+            },
+        }, add_meta=False, additionalProperties=True)
+
+        trs = TaskResultSet(4, 5000)
+        tr = TaskResult("bucket", 100, "seeded_task", "1.1.1",
+                        schema=BucketSchema)
+        tr.add("key1", "val1")
+        tr.add("key2", "val2")
+        tr.finish()
+        trs.add(tr)
+        bucket_tmoid = trs.get_output_tmoid("bucket", 100, schema=BucketSchema)
+        key1_tr = bucket_tmoid.get_data("key1")
+        key2_tr = bucket_tmoid.get_data("key2")
+
+        self.assertEqual(key1_tr, "val1")
+        self.assertEqual(key2_tr, "val2")
